OPTIONS NOCENTER NoSource NoNotes NoSpool NoDate NoNumber;
/* Generating multiple datasets of size 70 - Random Intercept LOGISTIC model power for marginal OR=2 */


/* writing log and output info to external files */
proc printto log='c:\DATA\POWER\LR_RandInt_power_N=70.log';
proc printto print='c:\DATA\POWER\LR_RandInt_power_N=70.lst';
run;

DATA parms;
* number of datasets ;
ndats = 5000;
* number of timepoints;
ntime = 5;
* number of subjects per group;
npergrp = 70;
* total number of subjects ;
nsubj = 2*npergrp;
* marginal odds ratio for the group difference;
mod = 2;
* ICC for repeated outcomes;
icc = .4;
* seed for random number generation;
seed   = 974657747;

******************************************************************************************;
* NOTHING BELOW NEEDS TO BE SPECIFIED;
******************************************************************************************;

* calculate the error & subject variances, and the subject-specific beta;
varerr = ((ATAN(1)*4)**2)/3;
varsub = varerr*(icc/(1-icc));
ssbeta = log(mod)*sqrt((varsub + varerr)/varerr);
data simdat; set parms;
ndat=1;
do while (ndat le ndats);
   n=1;
   do while (n le nsubj);
      grp = 0; if n > npergrp then grp = 1;
          subj = SQRT(varsub)*RANNOR(SEED);
          j=1;
          do while (j le ntime);
             exp1 =  ranexp(seed);
             exp2 =  ranexp(seed);
             err = LOG(exp1/exp2);
             ystar = ssbeta*grp + subj + err;
             y    = 0;if ystar > 0 then y = 1;
            output simdat;
          j+1;end;
   n+1;end;
ndat+1;end;


/* random intercept logistic regression model */
PROC GLIMMIX NOCLPRINT METHOD=QUAD(QPOINTS=5);
class n;
model y (DESCENDING) = grp /DIST=BINARY SOLUTION;
random intercept/subject=n;
by ndat;
ods output ParameterEstimates=parmest;
run;


data grpest; set parmest; by ndat;
/* select only the grp effect */
if effect = 'grp';


/* summarize the results of the regression model */
data sumres;
IF _N_ = 1 THEN set parms; set grpest;

reject = 0;
if (ABS(ESTIMATE/STDERR) > 1.95996) then reject = 1;



proc means noprint; var ndats npergrp ntime icc estimate ssbeta reject;
output out = outres  mean(ndats npergrp ntime icc estimate ssbeta reject) = ndatasets numpergrp numtime intclass estm truev rejrate;
run;


/* write out the results */
DATA outfile; set outres (keep = ndatasets numpergrp numtime intclass truev estm rejrate);
FILE 'c:\data\power\LR_RandInt_power_N=70.txt';
put (ndatasets numpergrp numtime) (6.0) (intclass) (8.4) (truev estm rejrate) (12.6);
run;

PROC EXPORT DATA= outfile
            OUTFILE= 'c:\data\power\LR_RandInt_power_N=70.xls'
            DBMS=EXCEL2000 REPLACE;
RUN;
